ACS ImageObjects — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »

# ACS ImageObjects

class `drizzlepac.acsData.` `ACSInputImage`(filename=None, group=None)

  Bases: `drizzlepac.imageObject.imageObject`

  `doUnitConversions`()
  `getdarkcurrent`(extver)

    Return the dark current for the ACS detector. This value will be contained within an instrument specific keyword. The value in the image header will be converted to units of electrons.

    Returns :
    | darkcurrent: float : Dark current value for the ACS detector in units of electrons.

  `SEPARATOR` = '_'

class `drizzlepac.acsData.` `WFCInputImage`(filename=None, group=None)

  Bases: `drizzlepac.acsData.ACSInputImage`

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

    This method gets called from processInput.

class `drizzlepac.acsData.` `HRCInputImage`(filename=None, group=None)

  Bases: `drizzlepac.acsData.ACSInputImage`

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

    This method gets called from processInput.

class `drizzlepac.acsData.` `SBCInputImage`(filename=None, group=None)

  Bases: `drizzlepac.acsData.ACSInputImage`

  `setInstrumentParameters`(instrpars)

    Sets the instrument parameters.

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »